package cc.winboll.studio.libappbase.utils;

/**
 * @Author ZhanGSKen<zhangsken@188.com>
 * @Date 2025/06/05 11:09
 */
import cc.winboll.studio.libappbase.LogUtils;
import cc.winboll.studio.libappbase.models.ResponseData;
import com.fasterxml.jackson.databind.ObjectMapper;
import java.net.URLDecoder;

public class JsonFormatter {
    public static final String TAG = "JsonFormatter";
    
    /**
     * 将包含 Unicode 转义的 JSON 字符串转为可读中文
     * @param jsonStr 原始 JSON 字符串（如：{"status":"error","message":"\u672a\u63a5\u6536\u5230 JSON \u6570\u636e"}）
     * @return 格式化后的中文消息字符串
     */
    public static String formatUnicodeToChinese(String jsonStr) {
        try {
            // 1. 使用 Jackson 解析 JSON 到对象
            ObjectMapper mapper = new ObjectMapper();
            ResponseData data = mapper.readValue(jsonStr, ResponseData.class);

            // 2. 解码 Unicode 转义字符（如 \u672a 转为中文）
            String decodedMessage = URLDecoder.decode(data.getMessage(), "UTF-8");

            // 3. 重新构建 JSON（可选：如需保留 JSON 格式）
            return "{\"status\":\"" + data.getStatus() + "\",\"message\":\"" + decodedMessage + "\"}";

        } catch (Exception e) {
            LogUtils.d(TAG, e, Thread.currentThread().getStackTrace());
            return jsonStr; // 解析失败时返回原始字符串
        }
    }

    // 示例用法
    /*public static void main(String[] args) {
        String rawJson = "{\"status\":\"error\",\"message\":\"\\u672a\\u63a5\\u6536\\u5230 JSON \\u6570\\u636e\"}";
        String formattedJson = formatUnicodeToChinese(rawJson);
        System.out.println("格式化前：" + rawJson);
        System.out.println("格式化后：" + formattedJson);
    }*/
}

